@@ -5,6 +5,11 @@ from .namespace import Namespace
 
 from rook.exceptions import RookKeyNotFound, RookAttributeNotFound, RookInvalidMethodArguments
 
+try:
+    from bson import ObjectId
+except ImportError:
+    pass # In case pymongo isn't loaded.
+
 
 class PythonObjectNamespace(Namespace):
     try:
@@ -69,7 +74,7 @@ class PythonObjectNamespace(Namespace):
 
         @classmethod
         def tailor_limits(cls, obj):
-            if isinstance(obj, six.string_types):
+            if isinstance(obj, (six.string_types,bytes)):
                 return PythonObjectNamespace.ObjectDumpConfig(1, 0, 0, cls.UNLIMITED_STRING)
             if isinstance(obj, (list, dict, set, tuple)) and len(obj) > cls.TOLERANT_MAX_WIDTH:
                 return PythonObjectNamespace.ObjectDumpConfig(max_width=cls.UNLIMITED_COLLECTION_WIDTH)
@@ -81,6 +86,14 @@ class PythonObjectNamespace(Namespace):
         self.obj = obj
         self.dump_config = dump_config or self.ObjectDumpConfig()
 
+        try:
+            if ObjectId and isinstance(obj, ObjectId):
+                self.obj = str(obj)
+                self.type = str(str)
+        except Exception:
+            # In case we have the case of BadObject, that throws an exception when you attempt to access any attribute.
+            pass
+    #
     @classmethod
     def get_common_type(cls, obj):
         # NOTE: This list is partially duplicated with the list in NamespaceSerializer._load_variant
