@@ -8,8 +8,27 @@ def on_lambda():
     return 'LAMBDA_TASK_ROOT' in os.environ
 
 
-def serverless_rook(f):
+def serverless_rook_params(*rook_args, **rook_kwargs):
+    def serverless_rook_inner(f):
 
+        if on_lambda():
+            @wraps(f)
+            def handler(*args, **kwargs):
+                rook.start(*rook_args, **rook_kwargs)
+
+                ret = f(*args, **kwargs)
+
+                rook.flush()
+                return ret
+        else:
+            handler = f
+
+        return handler
+
+    return serverless_rook_inner
+
+
+def serverless_rook(f):
     if on_lambda():
         @wraps(f)
         def handler(*args, **kwargs):
