@@ -156,12 +156,17 @@ static PythonOpcodeType GetOpcodeType(uint8 opcode) {
 
 // Gets the target offset of a branch instruction.
 static int GetBranchTarget(int offset, PythonInstruction instruction) {
+#if PY_VERSION_HEX >= 0x030A0000
+    int arg = instruction.argument*2;
+#else
+    int arg = instruction.argument;
+#endif
   switch (GetOpcodeType(instruction.opcode)) {
     case BRANCH_DELTA_OPCODE:
-      return offset + instruction.size + instruction.argument;
+      return offset + instruction.size + arg;
 
     case BRANCH_ABSOLUTE_OPCODE:
-      return instruction.argument;
+      return arg;
 
     default:
       DCHECK(false) << "Not a branch instruction";
@@ -502,6 +507,9 @@ static bool InsertAndUpdateBranchInstructions(
          it < instructions.end(); it++) {
       PythonInstruction instruction = it->instruction;
       int32 arg = static_cast<int32>(instruction.argument);
+#if PY_VERSION_HEX >= 0x030A0000
+      arg *= 2; // multiple for offset calculations
+#endif
       bool need_to_update = false;
       PythonOpcodeType opcode_type = GetOpcodeType(instruction.opcode);
       if (opcode_type == BRANCH_DELTA_OPCODE) {
@@ -520,6 +528,10 @@ static bool InsertAndUpdateBranchInstructions(
         need_to_update = insertion.current_offset < arg;
       }
 
+#if PY_VERSION_HEX >= 0x030A0000
+      arg /= 2; // restore
+#endif
+
       // If we are inserting the original method call instructions, we want to
       // update the current_offset of any instructions at or after. If we are
       // doing an EXTENDED_ARG insertion, we don't want to update the offset of
@@ -531,8 +543,13 @@ static bool InsertAndUpdateBranchInstructions(
       }
 
       if (need_to_update) {
+#if PY_VERSION_HEX >= 0x030A0000
+          uint16_t insertionSize = (insertion.size/2); // Surprise: https://github.com/python/cpython/commit/fcb55c0037baab6f98f91ee38ce84b6f874f034a#diff-96747735ee3c8aed3dd0f4c1b1ab0310eeb344577b14887cc9f6605892df47a8R345
+#else
+          uint16_t insertionSize = insertion.size;
+#endif
         PythonInstruction new_instruction =
-            PythonInstructionArg(instruction.opcode, arg + insertion.size);
+            PythonInstructionArg(instruction.opcode, arg + insertionSize);
         int size_diff = new_instruction.size - instruction.size;
         if (size_diff > 0) {
           insertions.push_back(Insertion { size_diff, it->current_offset });
@@ -739,8 +756,14 @@ bool BytecodeManipulator::AppendMethodCall(
     BytecodeManipulator::Data* data,
     int offset,
     int const_index) const {
-  PythonInstruction trampoline =
-      PythonInstructionArg(JUMP_ABSOLUTE, data->bytecode.size());
+
+#if PY_VERSION_HEX >= 0x030A0000
+    PythonInstruction trampoline =
+      PythonInstructionArg(JUMP_ABSOLUTE, (data->bytecode.size())/2);
+#else
+    PythonInstruction trampoline =
+      PythonInstructionArg(JUMP_ABSOLUTE, (data->bytecode.size()));
+#endif
 
   std::vector<PythonInstruction> relocated_instructions;
   int relocated_size = 0;
@@ -829,9 +852,15 @@ bool BytecodeManipulator::AppendMethodCall(
       appendix.end(),
       relocated_instructions.begin(),
       relocated_instructions.end());
+#if PY_VERSION_HEX >= 0x030A0000
   appendix.push_back(PythonInstructionArg(
       JUMP_ABSOLUTE,
-      offset + relocated_size));
+      (offset + relocated_size)/2));
+#else
+  appendix.push_back(PythonInstructionArg(
+      JUMP_ABSOLUTE,
+      (offset + relocated_size)));
+#endif
 
   // Write the appendix instructions.
   int pos = data->bytecode.size();
