@@ -20,7 +20,7 @@ from .trigger_services import TriggerServices
 from .services.monitor.monitor_service import MonitorService
 
 from rook.exceptions import RookInterfaceException, RookVersionNotSupported
-from rook.com_ws.agent_com_ws import AgentCom, thread_connection_type, SINGLE_THREAD_AGENT_COM
+from rook.com_ws.agent_com_ws import AgentCom
 from rook.com_ws.command_handler import CommandHandler
 from rook.serverless import on_lambda
 
@@ -144,15 +144,15 @@ class _Singleton(object):
         self._agent_com.restart()
 
     def pre_fork(self):
-        if self._agent_com is not None and thread_connection_type is SINGLE_THREAD_AGENT_COM:
+        if self._agent_com is not None:
             # to avoid new child to write father's fd in single-threaded communication
             self._agent_com.stop()
 
         self._trigger_services.pre_fork()
 
     def post_fork_recover(self):
-        if self._agent_com is not None and thread_connection_type is SINGLE_THREAD_AGENT_COM:
-            self._agent_com.start()
+        if self._agent_com is not None:
+            self._agent_com.restart()
 
         self._trigger_services.post_fork()
 
@@ -173,7 +173,7 @@ class _Singleton(object):
     def _check_version_supported():
         try:
             supported_platforms = ['pypy', 'cpython']
-            supported_version = ['2.7', '3.5', '3.6', '3.7', '3.8', '3.9']
+            supported_version = ['2.7', '3.5', '3.6', '3.7', '3.8', '3.9', '3.10']
 
             current_platform = platform.python_implementation().lower()
             if current_platform not in supported_platforms:
